@@ -1,10 +1,9 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Axis.pm 67466 2008-07-30T01:53:50.528367Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Axis.pm 72336 2008-09-06T14:09:33.087086Z daisuke  $
 
 package Google::Chart::Axis;
 use Moose;
 use Moose::Util::TypeConstraints;
 use Google::Chart::Axis::Item;
-use URI::Escape;
 
 with 'Google::Chart::QueryComponent';
 
@@ -40,6 +39,7 @@ has 'axes' => (
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
+no Moose::Util::TypeConstraints;
 
 sub as_query {
     my $self = shift;
